@@ -1,5 +1,5 @@
 /* gzip (GNU zip) -- compress files with zip algorithm and 'compress' interface
- * Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+ * Copyright (C) 1999, 2001, 2002 Free Software Foundation, Inc.
  * Copyright (C) 1992-1993 Jean-loup Gailly
  * The unzip code was written and put in the public domain by Mark Adler.
  * Portions of the lzw code are derived from the public domain 'compress'
@@ -11,7 +11,7 @@
  */
 
 static char  *license_msg[] = {
-"Copyright 2001 Free Software Foundation",
+"Copyright 2002 Free Software Foundation",
 "Copyright 1992-1993 Jean-loup Gailly",
 "This program comes with ABSOLUTELY NO WARRANTY.",
 "You may redistribute copies of this program",
@@ -234,7 +234,7 @@ off_t ifile_size;      /* input file size, -1 for devices (debug only) */
 char *env;            /* contents of GZIP env variable */
 char **args = NULL;   /* argv pointer if GZIP env variable defined */
 char *z_suffix;       /* default suffix (can be set with --suffix) */
-int  z_len;           /* strlen(z_suffix) */
+size_t z_len;         /* strlen(z_suffix) */
 
 off_t bytes_in;             /* number of input bytes */
 off_t bytes_out;            /* number of output bytes */
