@@ -27,18 +27,21 @@
      /* DJGPP version 1.09+ on MS-DOS.
       * The DJGPP 1.09 stat() function must be upgraded before gzip will
       * fully work.
-      * No need for DIRENT, since <unistd.h> defines POSIX_SOURCE which
-      * implies DIRENT.
+      * No need for HAVE_DIRENT_H, since <unistd.h> defines POSIX_SOURCE which
+      * implies HAVE_DIRENT_H.
       */
 #    define near
 #  else
 #    define MAXSEG_64K
 #    ifdef __TURBOC__
-#      define NO_UTIME
-#      define NO_OFF_T
+#      define off_t long
+#      ifdef __BORLANDC__
+#        define HAVE_DIRENT_H
+#        define HAVE_UTIME
+#      endif
+#      define HAVE_UTIME_H
 #    else /* MSC */
 #      define HAVE_SYS_UTIME_H
-#      define NO_UTIME_H
 #    endif
 #  endif
 #  define PATH_SEP2 '\\'
@@ -47,10 +50,10 @@
 #  define NO_MULTIPLE_DOTS
 #  define MAX_EXT_CHARS 3
 #  define Z_SUFFIX "z"
-#  define NO_CHOWN
 #  define PROTO
 #  define STDC_HEADERS
 #  define NO_SIZE_CHECK
+#  define UNLINK_READONLY_BUG
 #  define casemap(c) tolow(c) /* Force file names to lower case */
 #  include <io.h>
 #  define OS_CODE  0x00
@@ -70,40 +73,58 @@
 #    define NO_MULTIPLE_DOTS
 #    define MAX_EXT_CHARS 3
 #    define Z_SUFFIX "z"
+#    define casemap(c) tolow(c)
 #  endif
-#  define NO_CHOWN
 #  define PROTO
 #  define STDC_HEADERS
-#  define casemap(c) tolow(c)
+#  define UNLINK_READONLY_BUG
 #  include <io.h>
 #  define OS_CODE  0x06
 #  define SET_BINARY_MODE(fd) setmode(fd, O_BINARY)
 #  ifdef _MSC_VER
 #    define HAVE_SYS_UTIME_H
-#    define NO_UTIME_H
 #    define MAXSEG_64K
 #    undef near
 #    define near _near
 #  endif
 #  ifdef __EMX__
 #    define HAVE_SYS_UTIME_H
-#    define NO_UTIME_H
-#    define DIRENT
+#    define HAVE_DIRENT_H
 #    define EXPAND(argc,argv) \
        {_response(&argc, &argv); _wildcard(&argc, &argv);}
 #  endif
 #  ifdef __BORLANDC__
-#    define DIRENT
+#    define HAVE_DIRENT_H
+#    define HAVE_UTIME_H
 #  endif
 #  ifdef __ZTC__
 #    define NO_DIR
-#    define NO_UTIME_H
 #    include <dos.h>
 #    define EXPAND(argc,argv) \
        {response_expand(&argc, &argv);}
 #  endif
 #endif
 
+#ifdef WIN32 /* Windows NT */
+#  define HAVE_SYS_UTIME_H
+#  define PATH_SEP2 '\\'
+#  define PATH_SEP3 ':'
+#  define MAX_PATH_LEN  260
+#  define PROTO
+#  define STDC_HEADERS
+#  define SET_BINARY_MODE(fd) setmode(fd, O_BINARY)
+#  define UNLINK_READONLY_BUG
+#  include <io.h>
+#  include <malloc.h>
+#  ifdef NTFAT
+#    define NO_MULTIPLE_DOTS
+#    define MAX_EXT_CHARS 3
+#    define Z_SUFFIX "z"
+#    define casemap(c) tolow(c) /* Force file names to lower case */
+#  endif
+#  define OS_CODE  0x0b
+#endif
+
 #ifdef MSDOS
 #  ifdef __TURBOC__
 #    include <alloc.h>
@@ -136,31 +157,30 @@
 #  define OS_CODE  0x02
 #  define OPTIONS_VAR "GZIP_OPT"
 #  define STDC_HEADERS
-#  define NO_UTIME
 #  define EXPAND(argc,argv) vms_expand_args(&argc,&argv);
 #  include <file.h>
 #  define unlink delete
 #  ifdef VAXC
-#    define NO_FCNTL_H
 #    include <unixio.h>
+#  else
+#    define HAVE_FCNTL_H
 #  endif
 #endif
 
 #ifdef AMIGA
 #  define PATH_SEP2 ':'
 #  define STDC_HEADERS
-#  define casemap(c) tolow(c) /* Force file names to lower case */
 #  define OS_CODE  0x01
 #  define ASMV
 #  ifdef __GNUC__
-#    define DIRENT
+#    define HAVE_DIRENT_H
+#    define HAVE_FCNTL_H
 #    define HAVE_UNISTD_H
+#    define HAVE_CHOWN
+#    define HAVE_LSTAT
 #  else /* SASC */
 #    define NO_STDIN_FSTAT
-#    define SYSDIR
-#    define NO_SYMLINK
-#    define NO_CHOWN
-#    define NO_FCNTL_H
+#    define HAVE_SYS_DIR_H
 #    include <fcntl.h> /* for read() and write() */
 #    define direct dirent
      extern void _expand_args(int *argc, char ***argv);
@@ -173,16 +193,18 @@
 #  ifndef STDC_HEADERS
 #    define STDC_HEADERS
 #    define HAVE_UNISTD_H
-#    define DIRENT
+#    define HAVE_DIRENT_H
 #  endif
 #  define ASMV
 #  define OS_CODE  0x05
 #  ifdef TOSFS
-#    define NO_SYMLINK
+#    define PATH_SEP2 '\\'
+#    define PATH_SEP3 ':'
+#    define MAX_PATH_LEN  128
 #    define NO_MULTIPLE_DOTS
 #    define MAX_EXT_CHARS 3
 #    define Z_SUFFIX "z"
-#    define NO_CHOWN
+#    define casemap(c) tolow(c) /* Force file names to lower case */
 #  endif
 #endif
 
@@ -191,8 +213,6 @@
 #  define DYN_ALLOC
 #  define PROTO
 #  define NO_STDIN_FSTAT
-#  define NO_CHOWN
-#  define NO_UTIME
 #  define chmod(file, mode) (0)
 #  define OPEN(name, flags, mode) open(name, flags)
 #  define OS_CODE  0x07
@@ -204,13 +224,8 @@
 #ifdef __50SERIES /* Prime/PRIMOS */
 #  define PATH_SEP '>'
 #  define STDC_HEADERS
-#  define NO_MEMORY_H
-#  define NO_UTIME_H
-#  define NO_UTIME
-#  define NO_CHOWN 
 #  define NO_STDIN_FSTAT 
 #  define NO_SIZE_CHECK 
-#  define NO_SYMLINK
 #  define RECORD_IO  1
 #  define casemap(c)  tolow(c) /* Force file names to lower case */
 #  define put_char(c) put_byte((c) & 0x7F)
@@ -221,8 +236,8 @@
 #  endif
 #endif
 
-#ifdef WIN32
-#  define OS_CODE  0x0b
+#if defined(pyr) && !defined(NOMEMCPY) /* Pyramid */
+#  define NOMEMCPY /* problem with overlapping copies */
 #endif
 
 #ifdef TOPS20
